# ghrocker

## Overview

This is an extension for rocker https://github.com/osrf/rocker

It provides bindings to locally test a site expected to be hosted in github pages locally. 

## Usage

    ghrocker PATH_TO_GH_PAGES_REPOSITORY


The browse to http://localhost:4000
Or launch it via:

    sensible-browser http://localhost:4000
